@@ -39,7 +39,7 @@ class scoresWidget : public QWidget
 		QSize calcSize();
 
 	protected:
-		void paintEvent(QPaintEvent *);
+		void paintEvent(QPaintEvent *) override;
 	
 	private:
 		const QList< QPair<int, QString> > m_scores;
